@@ -49,6 +49,8 @@ pub enum SyntaxError {
     ArrowNotAllowed,
     ExportNotAllowed,
     GetterSetterCannotBeReadonly,
+    GetterParam,
+    SetterParam,
 
     TopLevelAwait,
     TopLevelAwaitInScript,
@@ -220,7 +222,6 @@ pub enum SyntaxError {
     TS1183,
     TS1184,
     TS1093,
-    TS1094,
     TS1196,
     TS1242,
     TS1243(JsWord, JsWord),
@@ -469,6 +470,8 @@ impl SyntaxError {
             SyntaxError::GetterSetterCannotBeReadonly => {
                 "A getter or a setter cannot be readonly".into()
             }
+            SyntaxError::GetterParam => "A `get` accessor cannot have parameters".into(),
+            SyntaxError::SetterParam => "A `set` accessor must have exactly one parameter".into(),
             SyntaxError::RestPatInSetter => "Rest pattern is not allowed in setter".into(),
 
             SyntaxError::GeneratorConstructor => "A constructor cannot be generator".into(),
@@ -548,9 +551,6 @@ impl SyntaxError {
             SyntaxError::TS1093 => {
                 "Type annotation cannot appear on a constructor declaration".into()
             }
-            SyntaxError::TS1094 => {
-                "A `set` accessor must have a corresponding `get` accessor".into()
-            }
             SyntaxError::TS1196 => "Catch clause variable cannot have a type annotation".into(),
             SyntaxError::TS1242 => {
                 "`abstract` modifier can only appear on a class or method declaration".into()
